/*
 *  firc.h from ObjectProDSP 0.1
 *  Copyright (C) 1994, Mountain Math Software, All rights reserved.
 *  Licensed for free use and distribution under version 2 of the Gnu General
 *  Public License. Please see file COPYING for details and restrictions.
 *  
 *  ObjectProDSP is a trademark of Mountain Math Software.
 */

int DeltaIn(int16 Resample, int16 ZeroPad) ;

int DeltaOut(int16 Resample,int16 ZeroPad) ;

