/*
 *  innode.h from ObjectProDSP 0.1
 *  Copyright (C) 1994, Mountain Math Software, All rights reserved.
 *  Licensed for free use and distribution under version 2 of the Gnu General
 *  Public License. Please see file COPYING for details and restrictions.
 *  
 *  ObjectProDSP is a trademark of Mountain Math Software.
 */

#ifndef INNODE_DOT_H
#define INNODE_DOT_H
#define __DSP_PP_TARGET_CODE__
#include "ObjProArith/hrdarth.h"
#include "ObjProDSPcom/drvintfc.h"

#include "ObjProDSP/portable.h"
#include "ObjProDSP/entenm.h"
#include "ObjProGen/debug.h"
#include "ObjProDSPcom/tarnod.h"
class InputNode: public TargetNode {
#line 105 "../innode.usr"
 
#include "ObjProDSPcom/innodex.h"
#line 25 "/usrb/dist/ftp/opd-0.1/src/include/ObjProDSPtar/ObjProUsr/innode.h"
	const char *  FileName_1;
	int16  Flags_2;
	int32  DeltaOut_3;
public:
	InputNode (const char * Name, const char * FileName, int16 Flags, 
		int32 DeltaOut,
		DfNodeInLink* in_links, DfNodeOutLink* out_links,
		int ** exec_seq,  NodeExecuteType exec_type,
		int delay);
	virtual ~InputNode();
	const char * GetFileName() const {return FileName_1;}
	int16 GetFlags() const {return Flags_2;}
	int32 GetDeltaOut() const {return DeltaOut_3;}
	virtual ErrCode DoNode(int32);
};

extern InputNode * InputNodeDef;


#endif /* #ifdef INNODE_DOT_H */
