/*
 *  outword.h from ObjectProDSP 0.1
 *  Copyright (C) 1994, Mountain Math Software, All rights reserved.
 *  Licensed for free use and distribution under version 2 of the Gnu General
 *  Public License. Please see file COPYING for details and restrictions.
 *  
 *  ObjectProDSP is a trademark of Mountain Math Software.
 */

#ifndef OUTWORD_DOT_H
#define OUTWORD_DOT_H
#include "ObjProArith/hrdarth.h"

#include "ObjProDSP/portable.h"
#include "ObjProDSP/entenm.h"
#include "ObjProGen/debug.h"
#include "ObjProUsr/dsplstr.h"

class OutputWord: public DisplayNodeStr {
#line 43 "../outword.usr"
 
	class BinaryOutputFile * file ;
	ErrCode node_state ;
	void ctor();
	void dtor();
	ErrCode kernel(int32 k);
#ifdef INTERACTIVE
    int InitAfterLinked(){return set_read_binary_flag(integer_read_flag) ;}
#endif
#line 31 "/usrb/dist/ftp/opd-0.1/src/include/ObjProDSPint/ObjProUsr/outword.h"
	int integer_read_flag ;
	virtual ErrCode EmitStaticInit(OutTokens& Out);
	virtual ErrCode EmitStaticCtorParameters(OutTokens& Out);
	const char *  FileName_1;
	int16  FormatOut_2;
public:
	OutputWord (const char * Name, const char * FileName, int16 FormatOut);
	virtual ~OutputWord();
	const char * GetFileName() const {return FileName_1;}
	int16 GetFormatOut() const {return FormatOut_2;}
	virtual int CheckSafeDelete() ;
	virtual ErrCode DoNode(int32);
	void Describe(OutTokens& Out, ListEntity Option);
	virtual int CppList(OutTokens& Out, CppListCmds Cmd);
	virtual double TimeFirst(DfNodeInLink *,DfNodeOutLink *);
};

extern OutputWord * OutputWordDef;


#endif /* #ifdef OUTWORD_DOT_H */
