/*
 *  dispmem.h from ObjectProDSP 0.1
 *  Copyright (C) 1994, Mountain Math Software, All rights reserved.
 *  Licensed for free use and distribution under version 2 of the Gnu General
 *  Public License. Please see file COPYING for details and restrictions.
 *  
 *  ObjectProDSP is a trademark of Mountain Math Software.
 */

void DisplayNodeStr::Raise()
{
    raise_window();
}

void DisplayNodeStr::Edit()
{
	add_to_net_graph();
}


Node& DisplayNodeStr::LinkIn(int16 Channel)
{
	DfNode::LinkIn(Channel);
	return *this ;
}

void DisplayNodeStr::DisplayInputTiming(int16 Channel)
{
	DfNode::DisplayInputTiming(Channel);
}

void DisplayNodeStr::NextFreeInput()
{
    DfNode::NextFreeInput();
}


void DisplayNodeStr::Unlink()
{
    DfNode::Unlink();
}


