/*
 *  hrdarth.h from ObjectProDSP 0.1
 *  Copyright (C) 1994, Mountain Math Software, All rights reserved.
 *  Licensed for free use and distribution under version 2 of the Gnu General
 *  Public License. Please see file COPYING for details and restrictions.
 *  
 *  ObjectProDSP is a trademark of Mountain Math Software.
 */
#ifndef HRDARTH_DOT_H
#define HRDARTH_DOT_H
#include "arthtyp.h"
typedef unsigned int BinMachWord ;
// Dummy
#define TheArithType  ArithType::ArithDouble
#endif /* #ifdef HRDARTH_DOT_H */
