/*
 *  addcmplx.h from ObjectProDSP 0.1
 *  Copyright (C) 1994, Mountain Math Software, All rights reserved.
 *  Licensed for free use and distribution under version 2 of the Gnu General
 *  Public License. Please see file COPYING for details and restrictions.
 *  
 *  ObjectProDSP is a trademark of Mountain Math Software.
 */
// phone structure to allow initializer for complex data

#ifndef ADDCMPLX_DOT_H
#define ADDCMPLX_DOT_H
struct complexType {
	double r;
	double i;
} ;
#endif /* #ifdef ADDCMPLX_DOT_H */
