/*
 *  text2.h from ObjectProDSP 0.1
 *  Copyright (C) 1994, Mountain Math Software, All rights reserved.
 *  Licensed for free use and distribution under version 2 of the Gnu General
 *  Public License. Please see file COPYING for details and restrictions.
 *  
 *  ObjectProDSP is a trademark of Mountain Math Software.
 */
#ifndef TEXT2_DOT_H
#define TEXT2_DOT_H
void EmbeddedTextOut(class TextFragmentList * , class ostream * ,
	class ConstStringList * AlreadyOut=0) ;


#endif /* #ifdef TEXT2_DOT_H */
