/*
 *  dynmnu.h from ObjectProDSP 0.1
 *  Copyright (C) 1994, Mountain Math Software, All rights reserved.
 *  Licensed for free use and distribution under version 2 of the Gnu General
 *  Public License. Please see file COPYING for details and restrictions.
 *  
 *  ObjectProDSP is a trademark of Mountain Math Software.
 */
#include "ObjProDSP/portable.h"
#include "ObjProComGui/dynmenu.h"

// Remote menu server

class MenuServer {
	class QueuedRequestList * QueuedRequests;
	int IsCommActive ;
public :
	MenuServer();
	~MenuServer();
	void SendMenuRequest(const char * ClassName, const char * Name,
		enum MenuServerCommand Command) ;
	void NewMenuItem(const char * ClassName, const char * Name);
	void SendNewMenuItem(const char * ClassName, const char * Name);
	void DeleteMenuItem(const char * ClassName, const char * Name);
	void SetCommActive();
	void DynamicPacketData(struct PacketHeader& Head, const char *Data) ;
} ;

extern MenuServer * TheMenuServer ;

void NewMenuItem(const char * ClassName, const char * Name);
void FindHomesForOrphanMenus();
