/*
 *  dspguicom.h from ObjectProDSP 0.1
 *  Copyright (C) 1994, Mountain Math Software, All rights reserved.
 *  Licensed for free use and distribution under version 2 of the Gnu General
 *  Public License. Please see file COPYING for details and restrictions.
 *  
 *  ObjectProDSP is a trademark of Mountain Math Software.
 */
#ifndef DSPGUICOM_DOT_H
#define DSPGUICOM_DOT_H
class DspGuiCommon {
public:
	static const char * default_prefix ;
	static const char * default_suffix ;
};

#endif /* #ifdef DSPGUICOM_DOT_H */
