/*
 *  getinf.h from ObjectProDSP 0.1
 *  Copyright (C) 1994, Mountain Math Software, All rights reserved.
 *  Licensed for free use and distribution under version 2 of the Gnu General
 *  Public License. Please see file COPYING for details and restrictions.
 *  
 *  ObjectProDSP is a trademark of Mountain Math Software.
 */
#include "ObjProDSPcom/infile.h"

int GetTheInputFile(TargetNode * node, const char * FileName,
	const char * NodeName, int16 Flags, InputFile** FilePtr) ;

