/*
 *  sysconst.h from ObjectProDSP 0.1
 *  Copyright (C) 1994, Mountain Math Software, All rights reserved.
 *  Licensed for free use and distribution under version 2 of the Gnu General
 *  Public License. Please see file COPYING for details and restrictions.
 *  
 *  ObjectProDSP is a trademark of Mountain Math Software.
 */
#ifndef SYSCONST_DOT_H
#define SYSCONST_DOT_H
const MaxNameSize = 64 ;
const OpenFileMode = 0600 ;

#endif /* #ifdef SYSCONST_DOT_H */
