/*
 *  dynmenu.h from ObjectProDSP 0.1
 *  Copyright (C) 1994, Mountain Math Software, All rights reserved.
 *  Licensed for free use and distribution under version 2 of the Gnu General
 *  Public License. Please see file COPYING for details and restrictions.
 *  
 *  ObjectProDSP is a trademark of Mountain Math Software.
 */
#ifndef DYNMENU_DOT_H
#define DYNMENU_DOT_H
/*  dynmenu.h   */
/*  Copyright 1989 Mountain Math Software  */
/*  All Rights Reserved                    */
enum MenuServerCommand {MenuServerNewMenuItem, MenuServerDeleteMenuItem,
	MenuServerAttachOrphan};


#endif /* #ifdef DYNMENU_DOT_H */
