/*
 *  timenum.h from ObjectProDSP 0.1
 *  Copyright (C) 1994, Mountain Math Software, All rights reserved.
 *  Licensed for free use and distribution under version 2 of the Gnu General
 *  Public License. Please see file COPYING for details and restrictions.
 *  
 *  ObjectProDSP is a trademark of Mountain Math Software.
 */
#ifndef TIMENUM_DOT_H
#define TIMENUM_DOT_H
enum TimingType {TimingTypeLinear, TimingTypeRandom} ;


#endif /* #ifdef TIMENUM_DOT_H */
