/*
 *  demod.h from ObjectProDSP 0.1
 *  Copyright (C) 1994, Mountain Math Software, All rights reserved.
 *  Licensed for free use and distribution under version 2 of the Gnu General
 *  Public License. Please see file COPYING for details and restrictions.
 *  
 *  ObjectProDSP is a trademark of Mountain Math Software.
 */

#ifndef DEMOD_DOT_H
#define DEMOD_DOT_H
#define __DSP_PP_TARGET_CODE__

#include "ObjProDSP/portable.h"
#include "ObjProDSP/entenm.h"
#include "ObjProGen/debug.h"
#include "ObjProDSPcom/tarnod.h"
class Demod: public TargetNode {
#line 39 "../demod.usr"
 
	int DemodFlag ;
	int32 DemodIndex ;
	complex DemodPhase ;
	complex DemodDeltaPhase ;
#line 26 "/usrb/dist/ftp/opd-0.1/src/include/ObjProDSPtar/ObjProUsr/demod.h"
	int16  DataType_1;
	double  DemodFreq_2;
public:
	Demod (const char * Name, int16 DataType, double DemodFreq,
		DfNodeInLink* in_links, DfNodeOutLink* out_links,
		int ** exec_seq,  NodeExecuteType exec_type,
		int delay);
	virtual ~Demod();
	int16 GetDataType() const {return DataType_1;}
	double GetDemodFreq() const {return DemodFreq_2;}
	virtual ErrCode DoNode(int32);
	void SetDemodFreq(double  DemodFreq) { DemodFreq_2 = DemodFreq; parameter_changed(); }
};

extern Demod * DemodDef;


#endif /* #ifdef DEMOD_DOT_H */
