/*
 *  menucmd.h from ObjectProDSP 0.1
 *  Copyright (C) 1994, Mountain Math Software, All rights reserved.
 *  Licensed for free use and distribution under version 2 of the Gnu General
 *  Public License. Please see file COPYING for details and restrictions.
 *  
 *  ObjectProDSP is a trademark of Mountain Math Software.
 */
#ifndef MENUCMD_DOT_H
#define MENUCMD_DOT_H
struct CommandParameters {
	int RoutineIndex ;
	int ParameterType ;
	int * IntParameters;
	char ** StringParameters ;
	double * FloatParameters ;
	int * StackParameters ;
	int wait:1 ;
	void Execute();
};

struct ParameterLimits {
	int IntLimits;
	int StringLimits ;
	int FloatLimits ;
	int StackLimits ;
} ;

typedef void (*ParameterizedActionCall) (...);

#endif /* #ifdef MENUCMD_DOT_H */
